[][src]Enum wishbone_tool::gdb::GdbCommand

pub enum GdbCommand {
    Unknown(String),
    MustReplyEmpty,
    SupportedQueries(String),
    StartNoAckMode,
    Disconnect,
    SetCurrentThread(u64),
    ContinueThread(i32),
    LastSignalPacket,
    GetThreadInfo,
    GetCurrentThreadId,
    CheckIsAttached,
    GetRegisters,
    GetRegister(u32),
    SetRegister(u32u32),
    SymbolsReady,
    ReadMemory(u32u32),
    WriteMemory(u32u32Vec<u32>),
    VContQuery,
    VContContinue,
    VContContinueFromSignal(String),
    VContStepFromSignal(String),
    Continue,
    Step,
    Interrupt,
    MonitorCommand(String),
    AddBreakpoint(BreakPointTypeu32u32),
    RemoveBreakpoint(BreakPointTypeu32u32),
    GetOffsets,
    ReadMemoryMap(u32u32),
    ReadFeature(Stringu32u32),
    TraceStatusQuery,
    ReadThreads(u32u32),
}

Variants

Unknown(String)

Server gave an unrecognized command

MustReplyEmpty

This should be responded to in the same way as Unknown(String), sent by the server to test how it responds to unknown packets.

SupportedQueries(String)

qSupported

StartNoAckMode

QStartNoAckMode

Disconnect

D

SetCurrentThread(u64)

Hg#

ContinueThread(i32)

Hc# (# may be -1)

LastSignalPacket

?

GetThreadInfo

qfThreadInfo

GetCurrentThreadId

qC

CheckIsAttached

qAttached

GetRegisters

g

GetRegister(u32)

p#

SetRegister(u32u32)

P#=#

SymbolsReady

qSymbol::

ReadMemory(u32u32)

m#,#

WriteMemory(u32u32Vec<u32>)

M#,#:#

VContQuery

vCont?

VContContinue

vCont;c

VContContinueFromSignal(String)

vCont;C04:0;c

VContStepFromSignal(String)

vCont;s:0;c

Continue

c

Step

s

Interrupt

Ctrl-C

MonitorCommand(String)

qRcmd,

AddBreakpoint(BreakPointTypeu32u32)

Z0,###,2

RemoveBreakpoint(BreakPointTypeu32u32)

z0,###,2

GetOffsets

qOffsets

ReadMemoryMap(u32u32)

qXfer:memory-map:read::

ReadFeature(Stringu32u32)

qXfer:features:read:target.xml:0,1000

TraceStatusQuery

qTStatus

ReadThreads(u32u32)

qXfer:threads:read::0,1000