[−][src]Enum wishbone_tool::gdb::GdbCommand
Variants
Unknown(String)Server gave an unrecognized command
This should be responded to in the same way as Unknown(String), sent by the server to test how it responds to unknown packets.
SupportedQueries(String)qSupported
QStartNoAckMode
D
SetCurrentThread(u64)Hg#
ContinueThread(i32)Hc# (# may be -1)
?
qfThreadInfo
qC
qAttached
g
GetRegister(u32)p#
P#=#
qSymbol::
m#,#
M#,#:#
vCont?
vCont;c
VContContinueFromSignal(String)vCont;C04:0;c
VContStepFromSignal(String)vCont;s:0;c
c
s
Ctrl-C
MonitorCommand(String)qRcmd,
AddBreakpoint(BreakPointType, u32, u32)Z0,###,2
RemoveBreakpoint(BreakPointType, u32, u32)z0,###,2
qOffsets
qXfer:memory-map:read::
qXfer:features:read:target.xml:0,1000
qTStatus
qXfer:threads:read::0,1000